@@ -1,11 +1,11 @@
 /*
- * $Id: Frontend.cs 423 2008-09-14 14:31:48Z meebey $
- * $URL: svn+ssh://svn.qnetp.net/svn/smuxi/smuxi/trunk/src/Frontend-Test/Frontend.cs $
- * $Rev: 423 $
- * $Author: meebey $
- * $Date: 2008-09-14 16:31:48 +0200 (Sun, 14 Sep 2008) $
+ * $Id$
+ * $URL$
+ * $Rev$
+ * $Author$
+ * $Date$
  *
- * smuxi - Smart MUltipleXed Irc
+ * Smuxi - Smart MUltipleXed Irc
  *
  * Copyright (c) 2005-2006 Mirco Bauer <meebey@meebey.net>
  *
@@ -147,11 +147,13 @@ namespace Smuxi.FrontendTest
                 switch (cd.Command) {
                     case "window":
                         bool found = false;
-                        foreach (ChatModel chatModel in _Session.Chats) {
-                            if (chatModel.Name.ToLower() == cd.Parameter.ToLower()) {
-                                found = true;
-                                ChangeActiveChat(chatModel);
-                                break;
+                        lock (_Session.Chats) {
+                            foreach (ChatModel chatModel in _Session.Chats) {
+                                if (chatModel.Name.ToLower() == cd.Parameter.ToLower()) {
+                                    found = true;
+                                    ChangeActiveChat(chatModel);
+                                    break;
+                                }
                             }
                         }
                         if (!found) {
